pub struct SalesFormsPrefs {Show 22 fields
pub sales_emaill_bcc: Option<Email>,
pub sales_email_cc: Option<Email>,
pub using_progress_invoicing: Option<bool>,
pub custom_field: Option<String>,
pub allow_service_date: Option<bool>,
pub estimate_message: Option<String>,
pub email_copy_to_company: Option<bool>,
pub default_customer_message: Option<String>,
pub allow_shipping: Option<bool>,
pub default_discount_account: Option<bool>,
pub ipn_support_enabled: Option<bool>,
pub e_transaction_payment_enabled: Option<bool>,
pub default_terms: Option<NtRef>,
pub allow_deposit: Option<bool>,
pub using_price_levels: Option<bool>,
pub default_shipping_account: Option<bool>,
pub e_transaction_attach_pdf: Option<bool>,
pub custom_txn_numbers: Option<bool>,
pub e_transaction_enabled_status: Option<String>,
pub allow_estimates: Option<bool>,
pub allow_discount: Option<bool>,
pub auto_apply_credit: Option<bool>,
}Expand description
Sales Forms Preferences
Represents the preferences for sales forms in QuickBooks.
Fields
sales_emaill_bcc: Option<Email>BCC email address for sales forms.
sales_email_cc: Option<Email>CC email address for sales forms.
using_progress_invoicing: Option<bool>Indicates if progress invoicing is being used.
custom_field: Option<String>Custom field for sales forms.
allow_service_date: Option<bool>Indicates if service date is allowed on sales forms.
estimate_message: Option<String>Default message for estimates.
email_copy_to_company: Option<bool>Indicates if a copy of the email should be sent to the company.
default_customer_message: Option<String>Default customer message for sales forms.
allow_shipping: Option<bool>Indicates if shipping is allowed on sales forms.
default_discount_account: Option<bool>Indicates if the default discount account is enabled.
ipn_support_enabled: Option<bool>Indicates if IPN support is enabled.
e_transaction_payment_enabled: Option<bool>Indicates if e-transaction payment is enabled.
default_terms: Option<NtRef>Default terms for sales forms.
allow_deposit: Option<bool>Indicates if deposits are allowed on sales forms.
using_price_levels: Option<bool>Indicates if price levels are being used.
default_shipping_account: Option<bool>Indicates if the default shipping account is enabled.
e_transaction_attach_pdf: Option<bool>Indicates if e-transaction PDF attachment is enabled.
custom_txn_numbers: Option<bool>Indicates if custom transaction numbers are allowed.
e_transaction_enabled_status: Option<String>Status of e-transaction enabled.
allow_estimates: Option<bool>Indicates if estimates are allowed.
allow_discount: Option<bool>Indicates if discounts are allowed.
auto_apply_credit: Option<bool>Indicates if auto-apply credit is enabled.