pub struct TaxCode {Show 13 fields
pub id: Option<String>,
pub sync_token: Option<String>,
pub name: Option<String>,
pub description: Option<String>,
pub active: Option<bool>,
pub sales_tax_code: Option<bool>,
pub purchase_tax_rate_list: Option<Vec<TaxRateDetail>>,
pub sales_tax_rate_list: Option<Vec<TaxRateDetail>>,
pub tax_group: Option<bool>,
pub taxable: Option<bool>,
pub hidden: Option<bool>,
pub meta_data: Option<MetaData>,
pub tax_code_config_type: Option<TaxCodeConfigType>,
}Fields
id: Option<String>The unique ID of the entity
sync_token: Option<String>The unique sync token of the entity, used for concurrency control
name: Option<String>Name of the tax code
description: Option<String>Description of the tax code
active: Option<bool>Indicates if the tax code is active
sales_tax_code: Option<bool>Indicates if the tax code is a sales tax code
purchase_tax_rate_list: Option<Vec<TaxRateDetail>>List of purchase tax rates associated with the tax code
sales_tax_rate_list: Option<Vec<TaxRateDetail>>List of sales tax rates associated with the tax code
tax_group: Option<bool>Indicates if the tax code is a tax group
taxable: Option<bool>Indicates if the tax code is taxable
Indicates if the tax code is hidden
meta_data: Option<MetaData>Metadata about the entity
tax_code_config_type: Option<TaxCodeConfigType>Flag indicating if the tax code is system defined or user defined