pub struct TaxRate {
pub id: Option<String>,
pub sync_token: Option<String>,
pub name: Option<String>,
pub rate_value: Option<f64>,
pub active: Option<bool>,
pub description: Option<String>,
pub agency_ref: Option<NtRef>,
pub meta_data: Option<MetaData>,
pub display_type: Option<String>,
pub tax_return_line_ref: Option<NtRef>,
pub effective_tax_rate: Option<EffectiveTaxRate>,
pub special_tax_type: Option<String>,
}Fields
id: Option<String>The unique ID of the entity
sync_token: Option<String>The unique sync token of the entity, used for concurrency control
name: Option<String>Name of the tax rate
rate_value: Option<f64>Rate percentage of the tax rate
active: Option<bool>Indicates if the tax rate is active
description: Option<String>Description of the tax rate
agency_ref: Option<NtRef>Reference to the tax agency associated with the tax rate
meta_data: Option<MetaData>Metadata about the entity
display_type: Option<String>TaxRate DisplayType enum which acts as display config.
tax_return_line_ref: Option<NtRef>Reference to the tax return line associated with the tax rate
effective_tax_rate: Option<EffectiveTaxRate>Effective tax rate details
special_tax_type: Option<String>Special tax type information