pub struct Term {
pub id: Option<String>,
pub sync_token: Option<String>,
pub name: Option<String>,
pub discount_percent: Option<u16>,
pub discount_days: Option<u16>,
pub active: Option<bool>,
pub term_type: Option<TermType>,
pub meta_data: Option<MetaData>,
pub day_of_month_due: Option<u16>,
pub discount_day_of_month: Option<u16>,
pub due_next_month_days: Option<u16>,
pub due_days: Option<u16>,
}Expand description
Term
represents the terms under which a sale is made, typically expressed in the form of days due after the goods are received.
API reference: https://developer.intuit.com/app/developer/qbo/docs/api/accounting/all-entities/term
Fields
id: Option<String>The unique ID of the entity
sync_token: Option<String>The unique sync token of the entity, used for concurrency control
name: Option<String>Name of the term
discount_percent: Option<u16>Percentage discount offered if paid within “DiscountDays”
discount_days: Option<u16>Number of days within which a payment must be made to avail the discount
used only when “due_days” is set
active: Option<bool>Indicates if the term is active
term_type: Option<TermType>Type of the term
meta_data: Option<MetaData>Metadata about the entity
day_of_month_due: Option<u16>Day of the month when the payment is due
required if “due_days” is not set
discount_day_of_month: Option<u16>Day of the month when the discount is applicable
required if “due_days” is not set
due_next_month_days: Option<u16>Payment due next month if issued that many days before the DayOfMonthDue. Required if DueDays not present.
due_days: Option<u16>Number of days from delivery of goods or services until the payment is due. Required if DayOfMonthDue not present